Rdocumentation
powered by
Learn R Programming
survJamda (version 1.1.4)
cal.cox.coef: Cox coefficient calculation.
Description
Calculate the Cox coefficients of covariates.
Usage
cal.cox.coef (gnExpMat, survivaltime, censor)
Arguments
gnExpMat
Matrix of gene expression data.
survivaltime
Vector of survival time.
censor
Vector of censoring status. 1 = event occurred, 0 = censored.
Value
Vector of Cox coefficients.
References
Yasrebi H, Sperisen P, Praz V, Bucher P, 2009 Can Survival Prediction Be Improved By Merging Gene Expression Data Sets?. PLoS ONE 4(10): e7431. doi:10.1371/journal.pone.0007431.