method="none".
The p.adjust function in the R stats package is used and all adjusted p-values not greater than 0.05 are retained if method != "none".
If perf.eval == "auc", time-dependent AUC and hazard ratio are used as the measure of performance, perf.eval == "cindex", concordance index defined in the survcomp package or perf.eval == "bsc", brier score defined in the survcomp package is used.