| Package: |
| survJamda |
| Type: |
| Package |
| Version: |
| 1.1.4 |
| Date: |
| 2015-11-01 |
| Depends: |
| survival, survivalROC, ecodist, survcomp, survJamda.data |
| License: |
| GPL (>= 2) |
| LazyLoad: |
| yes |
Yasrebi H. SurvJamda: an R package to predict patients' survival and risk assessment using joint analysis of microarray gene expression data. Bioinformatics. 2011 Apr 15;27(8):1168-9. doi: 10.1093/bioinformatics/btr103. Epub 2011 Mar 2. PubMed PMID: 21367873.
Yasrebi H., Sperisen P., Praz V., Bucher P., Can Survival Prediction Be Improved By Merging Gene Expression Data Sets?, PLoS ONE 4(10): e7431. doi:10.1371/journal.pone.0007431, 2009, PMID: 21367873.
Yasrebi, H. Prediction of survival and risk assessment using joint analysis of microarray gene expression data, PhD thesis, EPFL, Switzerland, doi:10.5075/Thesis 4494, 2010, PMID: 19851466.
coxph,
survivalROC,
corgen,
p.adjust,
concordance.index,
sbrier.score2proba